@@ -22,7 +22,7 @@ def get_template_path(template_name):
     return os.path.join(templates_path, template_name)
     
 
-def activate_venv(path):
+def activate_venv():
 
     parent = os.getcwd()
     os.system("python -m venv env")
@@ -31,8 +31,8 @@ def activate_venv(path):
     if OS == "Windows":
         env_activate_script = "Scripts"
 
-    print("---path ", path)
-    activate_file = os.path.join(path, "env", env_activate_script, "activate")
+    print("---path ", parent)
+    activate_file = os.path.join(parent, "env", env_activate_script, "activate")
     print("---activate_file ", activate_file)
     os.system(f"{activate_file} && pip install -r requirements.txt")
 
@@ -44,5 +44,5 @@ def main(template_name):
     project_path = os.path.join(template_path, template_name)
     print("---project_path", project_path)
     print("--res", res)
-    activate_venv(project_path)
+    activate_venv()
 
